import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ArtifactRegistryResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class RepositoriesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class FilesResource(googleapiclient.discovery.Resource):
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> FileHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListFilesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListFilesResponseHttpRequest,
                        previous_response: ListFilesResponse,
                    ) -> ListFilesResponseHttpRequest | None: ...

                @typing.type_check_only
                class PackagesResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class TagsResource(googleapiclient.discovery.Resource):
                        def create(
                            self,
                            *,
                            parent: str,
                            body: Tag = ...,
                            tagId: str = ...,
                            **kwargs: typing.Any
                        ) -> TagHttpRequest: ...
                        def delete(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> EmptyHttpRequest: ...
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> TagHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            filter: str = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListTagsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListTagsResponseHttpRequest,
                            previous_response: ListTagsResponse,
                        ) -> ListTagsResponseHttpRequest | None: ...
                        def patch(
                            self,
                            *,
                            name: str,
                            body: Tag = ...,
                            updateMask: str = ...,
                            **kwargs: typing.Any
                        ) -> TagHttpRequest: ...

                    @typing.type_check_only
                    class VersionsResource(googleapiclient.discovery.Resource):
                        def delete(
                            self, *, name: str, force: bool = ..., **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...
                        def get(
                            self,
                            *,
                            name: str,
                            view: typing_extensions.Literal[
                                "VERSION_VIEW_UNSPECIFIED", "BASIC", "FULL"
                            ] = ...,
                            **kwargs: typing.Any
                        ) -> VersionHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            orderBy: str = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            view: typing_extensions.Literal[
                                "VERSION_VIEW_UNSPECIFIED", "BASIC", "FULL"
                            ] = ...,
                            **kwargs: typing.Any
                        ) -> ListVersionsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListVersionsResponseHttpRequest,
                            previous_response: ListVersionsResponse,
                        ) -> ListVersionsResponseHttpRequest | None: ...

                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> PackageHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListPackagesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListPackagesResponseHttpRequest,
                        previous_response: ListPackagesResponse,
                    ) -> ListPackagesResponseHttpRequest | None: ...
                    def tags(self) -> TagsResource: ...
                    def versions(self) -> VersionsResource: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: Repository = ...,
                    repositoryId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> RepositoryHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListRepositoriesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListRepositoriesResponseHttpRequest,
                    previous_response: ListRepositoriesResponse,
                ) -> ListRepositoriesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Repository = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> RepositoryHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def files(self) -> FilesResource: ...
                def packages(self) -> PackagesResource: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def operations(self) -> OperationsResource: ...
            def repositories(self) -> RepositoriesResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> File: ...

@typing.type_check_only
class ListFilesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFilesResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListPackagesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPackagesResponse: ...

@typing.type_check_only
class ListRepositoriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRepositoriesResponse: ...

@typing.type_check_only
class ListTagsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTagsResponse: ...

@typing.type_check_only
class ListVersionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListVersionsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PackageHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Package: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class RepositoryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Repository: ...

@typing.type_check_only
class TagHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Tag: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...

@typing.type_check_only
class VersionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Version: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Actor(typing_extensions.TypedDict, total=False):
    displayName: str
    email: str
    googleSupport: bool

@typing.type_check_only
class Attachment(typing_extensions.TypedDict, total=False):
    createTime: str
    creator: Actor
    filename: str
    mimeType: str
    name: str
    sizeBytes: str

@typing.type_check_only
class Blobstore2Info(typing_extensions.TypedDict, total=False):
    blobGeneration: str
    blobId: str
    downloadReadHandle: str
    readToken: str
    uploadMetadataContainer: str

@typing.type_check_only
class Case(typing_extensions.TypedDict, total=False):
    classification: CaseClassification
    createTime: str
    creator: Actor
    description: str
    displayName: str
    escalated: bool
    name: str
    priority: typing_extensions.Literal[
        "PRIORITY_UNSPECIFIED", "P0", "P1", "P2", "P3", "P4"
    ]
    severity: typing_extensions.Literal[
        "SEVERITY_UNSPECIFIED", "S0", "S1", "S2", "S3", "S4"
    ]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "NEW",
        "IN_PROGRESS_GOOGLE_SUPPORT",
        "ACTION_REQUIRED",
        "SOLUTION_PROVIDED",
        "CLOSED",
    ]
    subscriberEmailAddresses: _list[str]
    testCase: bool
    timeZone: str
    updateTime: str

@typing.type_check_only
class CaseClassification(typing_extensions.TypedDict, total=False):
    displayName: str
    id: str

@typing.type_check_only
class CloseCaseRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Comment(typing_extensions.TypedDict, total=False):
    body: str
    createTime: str
    creator: Actor
    name: str
    plainTextBody: str

@typing.type_check_only
class CompositeMedia(typing_extensions.TypedDict, total=False):
    blobRef: str
    blobstore2Info: Blobstore2Info
    cosmoBinaryReference: str
    crc32cHash: int
    inline: str
    length: str
    md5Hash: str
    objectId: ObjectId
    path: str
    referenceType: typing_extensions.Literal[
        "PATH", "BLOB_REF", "INLINE", "BIGSTORE_REF", "COSMO_BINARY_REFERENCE"
    ]
    sha1Hash: str

@typing.type_check_only
class ContentTypeInfo(typing_extensions.TypedDict, total=False):
    bestGuess: str
    fromBytes: str
    fromFileName: str
    fromHeader: str
    fromUrlPath: str

@typing.type_check_only
class CreateAttachmentRequest(typing_extensions.TypedDict, total=False):
    attachment: Attachment

@typing.type_check_only
class DiffChecksumsResponse(typing_extensions.TypedDict, total=False):
    checksumsLocation: CompositeMedia
    chunkSizeBytes: str
    objectLocation: CompositeMedia
    objectSizeBytes: str
    objectVersion: str

@typing.type_check_only
class DiffDownloadResponse(typing_extensions.TypedDict, total=False):
    objectLocation: CompositeMedia

@typing.type_check_only
class DiffUploadRequest(typing_extensions.TypedDict, total=False):
    checksumsInfo: CompositeMedia
    objectInfo: CompositeMedia
    objectVersion: str

@typing.type_check_only
class DiffUploadResponse(typing_extensions.TypedDict, total=False):
    objectVersion: str
    originalObject: CompositeMedia

@typing.type_check_only
class DiffVersionResponse(typing_extensions.TypedDict, total=False):
    objectSizeBytes: str
    objectVersion: str

@typing.type_check_only
class DownloadParameters(typing_extensions.TypedDict, total=False):
    allowGzipCompression: bool
    ignoreRange: bool

@typing.type_check_only
class EscalateCaseRequest(typing_extensions.TypedDict, total=False):
    escalation: Escalation

@typing.type_check_only
class Escalation(typing_extensions.TypedDict, total=False):
    justification: str
    reason: typing_extensions.Literal[
        "REASON_UNSPECIFIED",
        "RESOLUTION_TIME",
        "TECHNICAL_EXPERTISE",
        "BUSINESS_IMPACT",
    ]

@typing.type_check_only
class ListAttachmentsResponse(typing_extensions.TypedDict, total=False):
    attachments: _list[Attachment]
    nextPageToken: str

@typing.type_check_only
class ListCasesResponse(typing_extensions.TypedDict, total=False):
    cases: _list[Case]
    nextPageToken: str

@typing.type_check_only
class ListCommentsResponse(typing_extensions.TypedDict, total=False):
    comments: _list[Comment]
    nextPageToken: str

@typing.type_check_only
class Media(typing_extensions.TypedDict, total=False):
    algorithm: str
    bigstoreObjectRef: str
    blobRef: str
    blobstore2Info: Blobstore2Info
    compositeMedia: _list[CompositeMedia]
    contentType: str
    contentTypeInfo: ContentTypeInfo
    cosmoBinaryReference: str
    crc32cHash: int
    diffChecksumsResponse: DiffChecksumsResponse
    diffDownloadResponse: DiffDownloadResponse
    diffUploadRequest: DiffUploadRequest
    diffUploadResponse: DiffUploadResponse
    diffVersionResponse: DiffVersionResponse
    downloadParameters: DownloadParameters
    filename: str
    hash: str
    hashVerified: bool
    inline: str
    isPotentialRetry: bool
    length: str
    md5Hash: str
    mediaId: str
    objectId: ObjectId
    path: str
    referenceType: typing_extensions.Literal[
        "PATH",
        "BLOB_REF",
        "INLINE",
        "GET_MEDIA",
        "COMPOSITE_MEDIA",
        "BIGSTORE_REF",
        "DIFF_VERSION_RESPONSE",
        "DIFF_CHECKSUMS_RESPONSE",
        "DIFF_DOWNLOAD_RESPONSE",
        "DIFF_UPLOAD_REQUEST",
        "DIFF_UPLOAD_RESPONSE",
        "COSMO_BINARY_REFERENCE",
        "ARBITRARY_BYTES",
    ]
    sha1Hash: str
    sha256Hash: str
    timestamp: str
    token: str

@typing.type_check_only
class ObjectId(typing_extensions.TypedDict, total=False):
    bucketName: str
    generation: str
    objectName: str

@typing.type_check_only
class SearchCaseClassificationsResponse(typing_extensions.TypedDict, total=False):
    caseClassifications: _list[CaseClassification]
    nextPageToken: str

@typing.type_check_only
class SearchCasesResponse(typing_extensions.TypedDict, total=False):
    cases: _list[Case]
    nextPageToken: str

@typing.type_check_only
class WorkflowOperationMetadata(typing_extensions.TypedDict, total=False):
    namespace: str
    operationAction: typing_extensions.Literal[
        "OPERATION_ACTION_UNSPECIFIED",
        "CREATE_SUPPORT_ACCOUNT",
        "UPDATE_SUPPORT_ACCOUNT",
        "PURCHASE_SUPPORT_ACCOUNT",
    ]
    workflowOperationType: typing_extensions.Literal[
        "UNKNOWN_OPERATION_TYPE", "WORKFLOWS_V1", "WORKFLOWS_V2"
    ]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1Analysis(
    typing_extensions.TypedDict, total=False
):
    analysisResult: GoogleCloudContactcenterinsightsV1AnalysisResult
    createTime: str
    name: str
    requestTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1AnalysisResult(
    typing_extensions.TypedDict, total=False
):
    callAnalysisMetadata: GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata
    endTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata(
    typing_extensions.TypedDict, total=False
):
    annotations: _list[GoogleCloudContactcenterinsightsV1CallAnnotation]
    entities: dict[str, typing.Any]
    intents: dict[str, typing.Any]
    issueModelResult: GoogleCloudContactcenterinsightsV1IssueModelResult
    phraseMatchers: dict[str, typing.Any]
    sentiments: _list[GoogleCloudContactcenterinsightsV1ConversationLevelSentiment]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1AnnotationBoundary(
    typing_extensions.TypedDict, total=False
):
    transcriptIndex: int
    wordIndex: int

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1AnswerFeedback(
    typing_extensions.TypedDict, total=False
):
    clicked: bool
    correctnessLevel: typing_extensions.Literal[
        "CORRECTNESS_LEVEL_UNSPECIFIED",
        "NOT_CORRECT",
        "PARTIALLY_CORRECT",
        "FULLY_CORRECT",
    ]
    displayed: bool

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ArticleSuggestionData(
    typing_extensions.TypedDict, total=False
):
    confidenceScore: float
    metadata: dict[str, typing.Any]
    queryRecord: str
    source: str
    title: str
    uri: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CalculateIssueModelStatsResponse(
    typing_extensions.TypedDict, total=False
):
    currentStats: GoogleCloudContactcenterinsightsV1IssueModelLabelStats

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CalculateStatsResponse(
    typing_extensions.TypedDict, total=False
):
    averageDuration: str
    averageTurnCount: int
    conversationCount: int
    conversationCountTimeSeries: GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries
    customHighlighterMatches: dict[str, typing.Any]
    issueMatches: dict[str, typing.Any]
    issueMatchesStats: dict[str, typing.Any]
    smartHighlighterMatches: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries(
    typing_extensions.TypedDict, total=False
):
    intervalDuration: str
    points: _list[
        GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval
    ]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval(
    typing_extensions.TypedDict, total=False
):
    conversationCount: int
    startTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CallAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationEndBoundary: GoogleCloudContactcenterinsightsV1AnnotationBoundary
    annotationStartBoundary: GoogleCloudContactcenterinsightsV1AnnotationBoundary
    channelTag: int
    entityMentionData: GoogleCloudContactcenterinsightsV1EntityMentionData
    holdData: GoogleCloudContactcenterinsightsV1HoldData
    intentMatchData: GoogleCloudContactcenterinsightsV1IntentMatchData
    interruptionData: GoogleCloudContactcenterinsightsV1InterruptionData
    phraseMatchData: GoogleCloudContactcenterinsightsV1PhraseMatchData
    sentimentData: GoogleCloudContactcenterinsightsV1SentimentData
    silenceData: GoogleCloudContactcenterinsightsV1SilenceData

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1Conversation(
    typing_extensions.TypedDict, total=False
):
    agentId: str
    callMetadata: GoogleCloudContactcenterinsightsV1ConversationCallMetadata
    createTime: str
    dataSource: GoogleCloudContactcenterinsightsV1ConversationDataSource
    dialogflowIntents: dict[str, typing.Any]
    duration: str
    expireTime: str
    labels: dict[str, typing.Any]
    languageCode: str
    latestAnalysis: GoogleCloudContactcenterinsightsV1Analysis
    medium: typing_extensions.Literal["MEDIUM_UNSPECIFIED", "PHONE_CALL", "CHAT"]
    name: str
    obfuscatedUserId: str
    runtimeAnnotations: _list[GoogleCloudContactcenterinsightsV1RuntimeAnnotation]
    startTime: str
    transcript: GoogleCloudContactcenterinsightsV1ConversationTranscript
    ttl: str
    turnCount: int
    updateTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationCallMetadata(
    typing_extensions.TypedDict, total=False
):
    agentChannel: int
    customerChannel: int

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationDataSource(
    typing_extensions.TypedDict, total=False
):
    dialogflowSource: GoogleCloudContactcenterinsightsV1DialogflowSource
    gcsSource: GoogleCloudContactcenterinsightsV1GcsSource

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationLevelSentiment(
    typing_extensions.TypedDict, total=False
):
    channelTag: int
    sentimentData: GoogleCloudContactcenterinsightsV1SentimentData

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationParticipant(
    typing_extensions.TypedDict, total=False
):
    dialogflowParticipant: str
    dialogflowParticipantName: str
    obfuscatedExternalUserId: str
    role: typing_extensions.Literal[
        "ROLE_UNSPECIFIED", "HUMAN_AGENT", "AUTOMATED_AGENT", "END_USER", "ANY_AGENT"
    ]
    userId: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationTranscript(
    typing_extensions.TypedDict, total=False
):
    transcriptSegments: _list[
        GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment
    ]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment(
    typing_extensions.TypedDict, total=False
):
    channelTag: int
    confidence: float
    dialogflowSegmentMetadata: GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
    languageCode: str
    messageTime: str
    segmentParticipant: GoogleCloudContactcenterinsightsV1ConversationParticipant
    sentiment: GoogleCloudContactcenterinsightsV1SentimentData
    text: str
    words: _list[
        GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentWordInfo
    ]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata(
    typing_extensions.TypedDict, total=False
):
    smartReplyAllowlistCovered: bool

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentWordInfo(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    endOffset: str
    startOffset: str
    word: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CreateAnalysisOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    conversation: str
    createTime: str
    endTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CreateIssueModelMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    request: GoogleCloudContactcenterinsightsV1CreateIssueModelRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1CreateIssueModelRequest(
    typing_extensions.TypedDict, total=False
):
    issueModel: GoogleCloudContactcenterinsightsV1IssueModel
    parent: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1DeleteIssueModelMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    request: GoogleCloudContactcenterinsightsV1DeleteIssueModelRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1DeleteIssueModelRequest(
    typing_extensions.TypedDict, total=False
):
    name: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1DeployIssueModelMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    request: GoogleCloudContactcenterinsightsV1DeployIssueModelRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1DeployIssueModelRequest(
    typing_extensions.TypedDict, total=False
):
    name: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1DeployIssueModelResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1DialogflowIntent(
    typing_extensions.TypedDict, total=False
):
    displayName: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1DialogflowInteractionData(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    dialogflowIntentId: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1DialogflowSource(
    typing_extensions.TypedDict, total=False
):
    audioUri: str
    dialogflowConversation: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1Entity(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    metadata: dict[str, typing.Any]
    salience: float
    sentiment: GoogleCloudContactcenterinsightsV1SentimentData
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "PERSON",
        "LOCATION",
        "ORGANIZATION",
        "EVENT",
        "WORK_OF_ART",
        "CONSUMER_GOOD",
        "OTHER",
        "PHONE_NUMBER",
        "ADDRESS",
        "DATE",
        "NUMBER",
        "PRICE",
    ]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1EntityMentionData(
    typing_extensions.TypedDict, total=False
):
    entityUniqueId: str
    sentiment: GoogleCloudContactcenterinsightsV1SentimentData
    type: typing_extensions.Literal["MENTION_TYPE_UNSPECIFIED", "PROPER", "COMMON"]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ExactMatchConfig(
    typing_extensions.TypedDict, total=False
):
    caseSensitive: bool

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    partialErrors: _list[GoogleRpcStatus]
    request: GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest(
    typing_extensions.TypedDict, total=False
):
    bigQueryDestination: GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination
    filter: str
    kmsKey: str
    parent: str
    writeDisposition: typing_extensions.Literal[
        "WRITE_DISPOSITION_UNSPECIFIED", "WRITE_TRUNCATE", "WRITE_APPEND"
    ]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination(
    typing_extensions.TypedDict, total=False
):
    dataset: str
    projectId: str
    table: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ExportInsightsDataResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1FaqAnswerData(
    typing_extensions.TypedDict, total=False
):
    answer: str
    confidenceScore: float
    metadata: dict[str, typing.Any]
    queryRecord: str
    question: str
    source: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1GcsSource(
    typing_extensions.TypedDict, total=False
):
    audioUri: str
    transcriptUri: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1HoldData(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1Intent(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    id: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IntentMatchData(
    typing_extensions.TypedDict, total=False
):
    intentUniqueId: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1InterruptionData(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1Issue(typing_extensions.TypedDict, total=False):
    createTime: str
    displayName: str
    name: str
    updateTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IssueAssignment(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    issue: str
    score: float

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IssueModel(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    displayName: str
    inputDataConfig: GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "UNDEPLOYED",
        "DEPLOYING",
        "DEPLOYED",
        "UNDEPLOYING",
        "DELETING",
    ]
    trainingStats: GoogleCloudContactcenterinsightsV1IssueModelLabelStats
    updateTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig(
    typing_extensions.TypedDict, total=False
):
    filter: str
    medium: typing_extensions.Literal["MEDIUM_UNSPECIFIED", "PHONE_CALL", "CHAT"]
    trainingConversationsCount: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IssueModelLabelStats(
    typing_extensions.TypedDict, total=False
):
    analyzedConversationsCount: str
    issueStats: dict[str, typing.Any]
    unclassifiedConversationsCount: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    issue: str
    labeledConversationsCount: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1IssueModelResult(
    typing_extensions.TypedDict, total=False
):
    issueModel: str
    issues: _list[GoogleCloudContactcenterinsightsV1IssueAssignment]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListAnalysesResponse(
    typing_extensions.TypedDict, total=False
):
    analyses: _list[GoogleCloudContactcenterinsightsV1Analysis]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListConversationsResponse(
    typing_extensions.TypedDict, total=False
):
    conversations: _list[GoogleCloudContactcenterinsightsV1Conversation]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListIssueModelsResponse(
    typing_extensions.TypedDict, total=False
):
    issueModels: _list[GoogleCloudContactcenterinsightsV1IssueModel]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListIssuesResponse(
    typing_extensions.TypedDict, total=False
):
    issues: _list[GoogleCloudContactcenterinsightsV1Issue]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    phraseMatchers: _list[GoogleCloudContactcenterinsightsV1PhraseMatcher]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1ListViewsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    views: _list[GoogleCloudContactcenterinsightsV1View]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1PhraseMatchData(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    phraseMatcher: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1PhraseMatchRule(
    typing_extensions.TypedDict, total=False
):
    config: GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig
    negated: bool
    query: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig(
    typing_extensions.TypedDict, total=False
):
    exactMatchConfig: GoogleCloudContactcenterinsightsV1ExactMatchConfig

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup(
    typing_extensions.TypedDict, total=False
):
    phraseMatchRules: _list[GoogleCloudContactcenterinsightsV1PhraseMatchRule]
    type: typing_extensions.Literal[
        "PHRASE_MATCH_RULE_GROUP_TYPE_UNSPECIFIED", "ALL_OF", "ANY_OF"
    ]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1PhraseMatcher(
    typing_extensions.TypedDict, total=False
):
    activationUpdateTime: str
    active: bool
    displayName: str
    name: str
    phraseMatchRuleGroups: _list[GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup]
    revisionCreateTime: str
    revisionId: str
    roleMatch: typing_extensions.Literal[
        "ROLE_UNSPECIFIED", "HUMAN_AGENT", "AUTOMATED_AGENT", "END_USER", "ANY_AGENT"
    ]
    type: typing_extensions.Literal[
        "PHRASE_MATCHER_TYPE_UNSPECIFIED", "ALL_OF", "ANY_OF"
    ]
    updateTime: str
    versionTag: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1RuntimeAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationId: str
    answerFeedback: GoogleCloudContactcenterinsightsV1AnswerFeedback
    articleSuggestion: GoogleCloudContactcenterinsightsV1ArticleSuggestionData
    createTime: str
    dialogflowInteraction: GoogleCloudContactcenterinsightsV1DialogflowInteractionData
    endBoundary: GoogleCloudContactcenterinsightsV1AnnotationBoundary
    faqAnswer: GoogleCloudContactcenterinsightsV1FaqAnswerData
    smartComposeSuggestion: GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData
    smartReply: GoogleCloudContactcenterinsightsV1SmartReplyData
    startBoundary: GoogleCloudContactcenterinsightsV1AnnotationBoundary

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1SentimentData(
    typing_extensions.TypedDict, total=False
):
    magnitude: float
    score: float

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1Settings(
    typing_extensions.TypedDict, total=False
):
    analysisConfig: GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
    conversationTtl: str
    createTime: str
    languageCode: str
    name: str
    pubsubNotificationSettings: dict[str, typing.Any]
    updateTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig(
    typing_extensions.TypedDict, total=False
):
    runtimeIntegrationAnalysisPercentage: float

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1SilenceData(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData(
    typing_extensions.TypedDict, total=False
):
    confidenceScore: float
    metadata: dict[str, typing.Any]
    queryRecord: str
    suggestion: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1SmartReplyData(
    typing_extensions.TypedDict, total=False
):
    confidenceScore: float
    metadata: dict[str, typing.Any]
    queryRecord: str
    reply: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1UndeployIssueModelMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    request: GoogleCloudContactcenterinsightsV1UndeployIssueModelRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1UndeployIssueModelRequest(
    typing_extensions.TypedDict, total=False
):
    name: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1UndeployIssueModelResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1View(typing_extensions.TypedDict, total=False):
    createTime: str
    displayName: str
    name: str
    updateTime: str
    value: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    conversation: str
    createTime: str
    endTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1CreateIssueModelMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    request: GoogleCloudContactcenterinsightsV1alpha1CreateIssueModelRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1CreateIssueModelRequest(
    typing_extensions.TypedDict, total=False
):
    issueModel: GoogleCloudContactcenterinsightsV1alpha1IssueModel
    parent: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1DeleteIssueModelMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    request: GoogleCloudContactcenterinsightsV1alpha1DeleteIssueModelRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1DeleteIssueModelRequest(
    typing_extensions.TypedDict, total=False
):
    name: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    request: GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelRequest(
    typing_extensions.TypedDict, total=False
):
    name: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1DeployIssueModelResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    partialErrors: _list[GoogleRpcStatus]
    request: GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequest(
    typing_extensions.TypedDict, total=False
):
    bigQueryDestination: GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination
    filter: str
    kmsKey: str
    parent: str
    writeDisposition: typing_extensions.Literal[
        "WRITE_DISPOSITION_UNSPECIFIED", "WRITE_TRUNCATE", "WRITE_APPEND"
    ]

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination(
    typing_extensions.TypedDict, total=False
):
    dataset: str
    projectId: str
    table: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1IssueModel(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    displayName: str
    inputDataConfig: GoogleCloudContactcenterinsightsV1alpha1IssueModelInputDataConfig
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "UNDEPLOYED",
        "DEPLOYING",
        "DEPLOYED",
        "UNDEPLOYING",
        "DELETING",
    ]
    trainingStats: GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStats
    updateTime: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1IssueModelInputDataConfig(
    typing_extensions.TypedDict, total=False
):
    filter: str
    medium: typing_extensions.Literal["MEDIUM_UNSPECIFIED", "PHONE_CALL", "CHAT"]
    trainingConversationsCount: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStats(
    typing_extensions.TypedDict, total=False
):
    analyzedConversationsCount: str
    issueStats: dict[str, typing.Any]
    unclassifiedConversationsCount: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    issue: str
    labeledConversationsCount: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    request: GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelRequest

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelRequest(
    typing_extensions.TypedDict, total=False
):
    name: str

@typing.type_check_only
class GoogleCloudContactcenterinsightsV1alpha1UndeployIssueModelResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[GoogleLongrunningOperation]

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class NotificationSetting(typing_extensions.TypedDict, total=False):
    name: str
    notificationTypes: _list[str]
    pubsubTopic: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class VaultResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class MattersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ExportsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, matterId: str, body: Export = ..., **kwargs: typing.Any
            ) -> ExportHttpRequest: ...
            def delete(
                self, *, matterId: str, exportId: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, matterId: str, exportId: str, **kwargs: typing.Any
            ) -> ExportHttpRequest: ...
            def list(
                self,
                *,
                matterId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListExportsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListExportsResponseHttpRequest,
                previous_response: ListExportsResponse,
            ) -> ListExportsResponseHttpRequest | None: ...

        @typing.type_check_only
        class HoldsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class AccountsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    matterId: str,
                    holdId: str,
                    body: HeldAccount = ...,
                    **kwargs: typing.Any
                ) -> HeldAccountHttpRequest: ...
                def delete(
                    self,
                    *,
                    matterId: str,
                    holdId: str,
                    accountId: str,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def list(
                    self, *, matterId: str, holdId: str, **kwargs: typing.Any
                ) -> ListHeldAccountsResponseHttpRequest: ...

            def addHeldAccounts(
                self,
                *,
                matterId: str,
                holdId: str,
                body: AddHeldAccountsRequest = ...,
                **kwargs: typing.Any
            ) -> AddHeldAccountsResponseHttpRequest: ...
            def create(
                self, *, matterId: str, body: Hold = ..., **kwargs: typing.Any
            ) -> HoldHttpRequest: ...
            def delete(
                self, *, matterId: str, holdId: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self,
                *,
                matterId: str,
                holdId: str,
                view: typing_extensions.Literal[
                    "HOLD_VIEW_UNSPECIFIED", "BASIC_HOLD", "FULL_HOLD"
                ] = ...,
                **kwargs: typing.Any
            ) -> HoldHttpRequest: ...
            def list(
                self,
                *,
                matterId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal[
                    "HOLD_VIEW_UNSPECIFIED", "BASIC_HOLD", "FULL_HOLD"
                ] = ...,
                **kwargs: typing.Any
            ) -> ListHoldsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListHoldsResponseHttpRequest,
                previous_response: ListHoldsResponse,
            ) -> ListHoldsResponseHttpRequest | None: ...
            def removeHeldAccounts(
                self,
                *,
                matterId: str,
                holdId: str,
                body: RemoveHeldAccountsRequest = ...,
                **kwargs: typing.Any
            ) -> RemoveHeldAccountsResponseHttpRequest: ...
            def update(
                self,
                *,
                matterId: str,
                holdId: str,
                body: Hold = ...,
                **kwargs: typing.Any
            ) -> HoldHttpRequest: ...
            def accounts(self) -> AccountsResource: ...

        @typing.type_check_only
        class SavedQueriesResource(googleapiclient.discovery.Resource):
            def create(
                self, *, matterId: str, body: SavedQuery = ..., **kwargs: typing.Any
            ) -> SavedQueryHttpRequest: ...
            def delete(
                self, *, matterId: str, savedQueryId: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, matterId: str, savedQueryId: str, **kwargs: typing.Any
            ) -> SavedQueryHttpRequest: ...
            def list(
                self,
                *,
                matterId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListSavedQueriesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListSavedQueriesResponseHttpRequest,
                previous_response: ListSavedQueriesResponse,
            ) -> ListSavedQueriesResponseHttpRequest | None: ...

        def addPermissions(
            self,
            *,
            matterId: str,
            body: AddMatterPermissionsRequest = ...,
            **kwargs: typing.Any
        ) -> MatterPermissionHttpRequest: ...
        def close(self, *, matterId: str, body: CloseMatterRequest = ..., **kwargs: typing.Any) -> CloseMatterResponseHttpRequest: ...  # type: ignore
        def count(
            self,
            *,
            matterId: str,
            body: CountArtifactsRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def create(
            self, *, body: Matter = ..., **kwargs: typing.Any
        ) -> MatterHttpRequest: ...
        def delete(
            self, *, matterId: str, **kwargs: typing.Any
        ) -> MatterHttpRequest: ...
        def get(
            self,
            *,
            matterId: str,
            view: typing_extensions.Literal["VIEW_UNSPECIFIED", "BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> MatterHttpRequest: ...
        def list(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            state: typing_extensions.Literal[
                "STATE_UNSPECIFIED", "OPEN", "CLOSED", "DELETED"
            ] = ...,
            view: typing_extensions.Literal["VIEW_UNSPECIFIED", "BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> ListMattersResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListMattersResponseHttpRequest,
            previous_response: ListMattersResponse,
        ) -> ListMattersResponseHttpRequest | None: ...
        def removePermissions(
            self,
            *,
            matterId: str,
            body: RemoveMatterPermissionsRequest = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def reopen(
            self,
            *,
            matterId: str,
            body: ReopenMatterRequest = ...,
            **kwargs: typing.Any
        ) -> ReopenMatterResponseHttpRequest: ...
        def undelete(
            self,
            *,
            matterId: str,
            body: UndeleteMatterRequest = ...,
            **kwargs: typing.Any
        ) -> MatterHttpRequest: ...
        def update(
            self, *, matterId: str, body: Matter = ..., **kwargs: typing.Any
        ) -> MatterHttpRequest: ...
        def exports(self) -> ExportsResource: ...
        def holds(self) -> HoldsResource: ...
        def savedQueries(self) -> SavedQueriesResource: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def cancel(
            self, *, name: str, body: CancelOperationRequest = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            name: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListOperationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListOperationsResponseHttpRequest,
            previous_response: ListOperationsResponse,
        ) -> ListOperationsResponseHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def matters(self) -> MattersResource: ...
    def operations(self) -> OperationsResource: ...

@typing.type_check_only
class AddHeldAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AddHeldAccountsResponse: ...

@typing.type_check_only
class CloseMatterResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CloseMatterResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ExportHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Export: ...

@typing.type_check_only
class HeldAccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> HeldAccount: ...

@typing.type_check_only
class HoldHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Hold: ...

@typing.type_check_only
class ListExportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListExportsResponse: ...

@typing.type_check_only
class ListHeldAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListHeldAccountsResponse: ...

@typing.type_check_only
class ListHoldsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListHoldsResponse: ...

@typing.type_check_only
class ListMattersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListMattersResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListSavedQueriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSavedQueriesResponse: ...

@typing.type_check_only
class MatterHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Matter: ...

@typing.type_check_only
class MatterPermissionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MatterPermission: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class RemoveHeldAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RemoveHeldAccountsResponse: ...

@typing.type_check_only
class ReopenMatterResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReopenMatterResponse: ...

@typing.type_check_only
class SavedQueryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SavedQuery: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AclEntry(typing_extensions.TypedDict, total=False):
    expirationTime: str
    kind: str
    name: str
    value: str

@typing.type_check_only
class ApiWarning(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal[
        "SQL_API_WARNING_CODE_UNSPECIFIED",
        "REGION_UNREACHABLE",
        "MAX_RESULTS_EXCEEDS_LIMIT",
    ]
    message: str
    region: str

@typing.type_check_only
class BackupConfiguration(typing_extensions.TypedDict, total=False):
    backupRetentionSettings: BackupRetentionSettings
    binaryLogEnabled: bool
    enabled: bool
    kind: str
    location: str
    pointInTimeRecoveryEnabled: bool
    replicationLogArchivingEnabled: bool
    startTime: str
    transactionLogRetentionDays: int

@typing.type_check_only
class BackupContext(typing_extensions.TypedDict, total=False):
    backupId: str
    kind: str

@typing.type_check_only
class BackupRetentionSettings(typing_extensions.TypedDict, total=False):
    retainedBackups: int
    retentionUnit: typing_extensions.Literal["RETENTION_UNIT_UNSPECIFIED", "COUNT"]

@typing.type_check_only
class BackupRun(typing_extensions.TypedDict, total=False):
    backupKind: typing_extensions.Literal[
        "SQL_BACKUP_KIND_UNSPECIFIED", "SNAPSHOT", "PHYSICAL"
    ]
    description: str
    diskEncryptionConfiguration: DiskEncryptionConfiguration
    diskEncryptionStatus: DiskEncryptionStatus
    endTime: str
    enqueuedTime: str
    error: OperationError
    id: str
    instance: str
    kind: str
    location: str
    selfLink: str
    startTime: str
    status: typing_extensions.Literal[
        "SQL_BACKUP_RUN_STATUS_UNSPECIFIED",
        "ENQUEUED",
        "OVERDUE",
        "RUNNING",
        "FAILED",
        "SUCCESSFUL",
        "SKIPPED",
        "DELETION_PENDING",
        "DELETION_FAILED",
        "DELETED",
    ]
    timeZone: str
    type: typing_extensions.Literal[
        "SQL_BACKUP_RUN_TYPE_UNSPECIFIED", "AUTOMATED", "ON_DEMAND"
    ]
    windowStartTime: str

@typing.type_check_only
class BackupRunsListResponse(typing_extensions.TypedDict, total=False):
    items: _list[BackupRun]
    kind: str
    nextPageToken: str

@typing.type_check_only
class BinLogCoordinates(typing_extensions.TypedDict, total=False):
    binLogFileName: str
    binLogPosition: str
    kind: str

@typing.type_check_only
class CloneContext(typing_extensions.TypedDict, total=False):
    allocatedIpRange: str
    binLogCoordinates: BinLogCoordinates
    databaseNames: _list[str]
    destinationInstanceName: str
    kind: str
    pitrTimestampMs: str
    pointInTime: str

@typing.type_check_only
class ConnectSettings(typing_extensions.TypedDict, total=False):
    backendType: typing_extensions.Literal[
        "SQL_BACKEND_TYPE_UNSPECIFIED", "FIRST_GEN", "SECOND_GEN", "EXTERNAL"
    ]
    databaseVersion: typing_extensions.Literal[
        "SQL_DATABASE_VERSION_UNSPECIFIED",
        "MYSQL_5_1",
        "MYSQL_5_5",
        "MYSQL_5_6",
        "MYSQL_5_7",
        "SQLSERVER_2017_STANDARD",
        "SQLSERVER_2017_ENTERPRISE",
        "SQLSERVER_2017_EXPRESS",
        "SQLSERVER_2017_WEB",
        "POSTGRES_9_6",
        "POSTGRES_10",
        "POSTGRES_11",
        "POSTGRES_12",
        "POSTGRES_13",
        "POSTGRES_14",
        "MYSQL_8_0",
        "MYSQL_8_0_18",
        "MYSQL_8_0_26",
        "MYSQL_8_0_27",
        "MYSQL_8_0_28",
        "MYSQL_8_0_29",
        "MYSQL_8_0_30",
        "SQLSERVER_2019_STANDARD",
        "SQLSERVER_2019_ENTERPRISE",
        "SQLSERVER_2019_EXPRESS",
        "SQLSERVER_2019_WEB",
    ]
    ipAddresses: _list[IpMapping]
    kind: str
    region: str
    serverCaCert: SslCert

@typing.type_check_only
class Database(typing_extensions.TypedDict, total=False):
    charset: str
    collation: str
    etag: str
    instance: str
    kind: str
    name: str
    project: str
    selfLink: str
    sqlserverDatabaseDetails: SqlServerDatabaseDetails

@typing.type_check_only
class DatabaseFlags(typing_extensions.TypedDict, total=False):
    name: str
    value: str

@typing.type_check_only
class DatabaseInstance(typing_extensions.TypedDict, total=False):
    availableMaintenanceVersions: _list[str]
    backendType: typing_extensions.Literal[
        "SQL_BACKEND_TYPE_UNSPECIFIED", "FIRST_GEN", "SECOND_GEN", "EXTERNAL"
    ]
    connectionName: str
    createTime: str
    currentDiskSize: str
    databaseInstalledVersion: str
    databaseVersion: typing_extensions.Literal[
        "SQL_DATABASE_VERSION_UNSPECIFIED",
        "MYSQL_5_1",
        "MYSQL_5_5",
        "MYSQL_5_6",
        "MYSQL_5_7",
        "SQLSERVER_2017_STANDARD",
        "SQLSERVER_2017_ENTERPRISE",
        "SQLSERVER_2017_EXPRESS",
        "SQLSERVER_2017_WEB",
        "POSTGRES_9_6",
        "POSTGRES_10",
        "POSTGRES_11",
        "POSTGRES_12",
        "POSTGRES_13",
        "POSTGRES_14",
        "MYSQL_8_0",
        "MYSQL_8_0_18",
        "MYSQL_8_0_26",
        "MYSQL_8_0_27",
        "MYSQL_8_0_28",
        "MYSQL_8_0_29",
        "MYSQL_8_0_30",
        "SQLSERVER_2019_STANDARD",
        "SQLSERVER_2019_ENTERPRISE",
        "SQLSERVER_2019_EXPRESS",
        "SQLSERVER_2019_WEB",
    ]
    diskEncryptionConfiguration: DiskEncryptionConfiguration
    diskEncryptionStatus: DiskEncryptionStatus
    etag: str
    failoverReplica: dict[str, typing.Any]
    gceZone: str
    instanceType: typing_extensions.Literal[
        "SQL_INSTANCE_TYPE_UNSPECIFIED",
        "CLOUD_SQL_INSTANCE",
        "ON_PREMISES_INSTANCE",
        "READ_REPLICA_INSTANCE",
    ]
    ipAddresses: _list[IpMapping]
    ipv6Address: str
    kind: str
    maintenanceVersion: str
    masterInstanceName: str
    maxDiskSize: str
    name: str
    onPremisesConfiguration: OnPremisesConfiguration
    outOfDiskReport: SqlOutOfDiskReport
    project: str
    region: str
    replicaConfiguration: ReplicaConfiguration
    replicaNames: _list[str]
    rootPassword: str
    satisfiesPzs: bool
    scheduledMaintenance: SqlScheduledMaintenance
    secondaryGceZone: str
    selfLink: str
    serverCaCert: SslCert
    serviceAccountEmailAddress: str
    settings: Settings
    state: typing_extensions.Literal[
        "SQL_INSTANCE_STATE_UNSPECIFIED",
        "RUNNABLE",
        "SUSPENDED",
        "PENDING_DELETE",
        "PENDING_CREATE",
        "MAINTENANCE",
        "FAILED",
        "ONLINE_MAINTENANCE",
    ]
    suspensionReason: _list[str]

@typing.type_check_only
class DatabasesListResponse(typing_extensions.TypedDict, total=False):
    items: _list[Database]
    kind: str

@typing.type_check_only
class DemoteMasterConfiguration(typing_extensions.TypedDict, total=False):
    kind: str
    mysqlReplicaConfiguration: DemoteMasterMySqlReplicaConfiguration

@typing.type_check_only
class DemoteMasterContext(typing_extensions.TypedDict, total=False):
    kind: str
    masterInstanceName: str
    replicaConfiguration: DemoteMasterConfiguration
    skipReplicationSetup: bool
    verifyGtidConsistency: bool

@typing.type_check_only
class DemoteMasterMySqlReplicaConfiguration(typing_extensions.TypedDict, total=False):
    caCertificate: str
    clientCertificate: str
    clientKey: str
    kind: str
    password: str
    username: str

@typing.type_check_only
class DenyMaintenancePeriod(typing_extensions.TypedDict, total=False):
    endDate: str
    startDate: str
    time: str

@typing.type_check_only
class DiskEncryptionConfiguration(typing_extensions.TypedDict, total=False):
    kind: str
    kmsKeyName: str

@typing.type_check_only
class DiskEncryptionStatus(typing_extensions.TypedDict, total=False):
    kind: str
    kmsKeyVersionName: str

@typing.type_check_only
class ExportContext(typing_extensions.TypedDict, total=False):
    csvExportOptions: dict[str, typing.Any]
    databases: _list[str]
    fileType: typing_extensions.Literal[
        "SQL_FILE_TYPE_UNSPECIFIED", "SQL", "CSV", "BAK"
    ]
    kind: str
    offload: bool
    sqlExportOptions: dict[str, typing.Any]
    uri: str

@typing.type_check_only
class FailoverContext(typing_extensions.TypedDict, total=False):
    kind: str
    settingsVersion: str

@typing.type_check_only
class Flag(typing_extensions.TypedDict, total=False):
    allowedIntValues: _list[str]
    allowedStringValues: _list[str]
    appliesTo: _list[str]
    inBeta: bool
    kind: str
    maxValue: str
    minValue: str
    name: str
    requiresRestart: bool
    type: typing_extensions.Literal[
        "SQL_FLAG_TYPE_UNSPECIFIED",
        "BOOLEAN",
        "STRING",
        "INTEGER",
        "NONE",
        "MYSQL_TIMEZONE_OFFSET",
        "FLOAT",
        "REPEATED_STRING",
    ]

@typing.type_check_only
class FlagsListResponse(typing_extensions.TypedDict, total=False):
    items: _list[Flag]
    kind: str

@typing.type_check_only
class GenerateEphemeralCertRequest(typing_extensions.TypedDict, total=False):
    access_token: str
    public_key: str
    readTime: str
    validDuration: str

@typing.type_check_only
class GenerateEphemeralCertResponse(typing_extensions.TypedDict, total=False):
    ephemeralCert: SslCert

@typing.type_check_only
class ImportContext(typing_extensions.TypedDict, total=False):
    bakImportOptions: dict[str, typing.Any]
    csvImportOptions: dict[str, typing.Any]
    database: str
    fileType: typing_extensions.Literal[
        "SQL_FILE_TYPE_UNSPECIFIED", "SQL", "CSV", "BAK"
    ]
    importUser: str
    kind: str
    uri: str

@typing.type_check_only
class InsightsConfig(typing_extensions.TypedDict, total=False):
    queryInsightsEnabled: bool
    queryPlansPerMinute: int
    queryStringLength: int
    recordApplicationTags: bool
    recordClientAddress: bool

@typing.type_check_only
class InstanceReference(typing_extensions.TypedDict, total=False):
    name: str
    project: str
    region: str

@typing.type_check_only
class InstancesCloneRequest(typing_extensions.TypedDict, total=False):
    cloneContext: CloneContext

@typing.type_check_only
class InstancesDemoteMasterRequest(typing_extensions.TypedDict, total=False):
    demoteMasterContext: DemoteMasterContext

@typing.type_check_only
class InstancesExportRequest(typing_extensions.TypedDict, total=False):
    exportContext: ExportContext

@typing.type_check_only
class InstancesFailoverRequest(typing_extensions.TypedDict, total=False):
    failoverContext: FailoverContext

@typing.type_check_only
class InstancesImportRequest(typing_extensions.TypedDict, total=False):
    importContext: ImportContext

@typing.type_check_only
class InstancesListResponse(typing_extensions.TypedDict, total=False):
    items: _list[DatabaseInstance]
    kind: str
    nextPageToken: str
    warnings: _list[ApiWarning]

@typing.type_check_only
class InstancesListServerCasResponse(typing_extensions.TypedDict, total=False):
    activeVersion: str
    certs: _list[SslCert]
    kind: str

@typing.type_check_only
class InstancesRestoreBackupRequest(typing_extensions.TypedDict, total=False):
    restoreBackupContext: RestoreBackupContext

@typing.type_check_only
class InstancesRotateServerCaRequest(typing_extensions.TypedDict, total=False):
    rotateServerCaContext: RotateServerCaContext

@typing.type_check_only
class InstancesTruncateLogRequest(typing_extensions.TypedDict, total=False):
    truncateLogContext: TruncateLogContext

@typing.type_check_only
class IpConfiguration(typing_extensions.TypedDict, total=False):
    allocatedIpRange: str
    authorizedNetworks: _list[AclEntry]
    ipv4Enabled: bool
    privateNetwork: str
    requireSsl: bool

@typing.type_check_only
class IpMapping(typing_extensions.TypedDict, total=False):
    ipAddress: str
    timeToRetire: str
    type: typing_extensions.Literal[
        "SQL_IP_ADDRESS_TYPE_UNSPECIFIED",
        "PRIMARY",
        "OUTGOING",
        "PRIVATE",
        "MIGRATED_1ST_GEN",
    ]

@typing.type_check_only
class LocationPreference(typing_extensions.TypedDict, total=False):
    followGaeApplication: str
    kind: str
    secondaryZone: str
    zone: str

@typing.type_check_only
class MaintenanceWindow(typing_extensions.TypedDict, total=False):
    day: int
    hour: int
    kind: str
    updateTrack: typing_extensions.Literal[
        "SQL_UPDATE_TRACK_UNSPECIFIED", "canary", "stable"
    ]

@typing.type_check_only
class MySqlReplicaConfiguration(typing_extensions.TypedDict, total=False):
    caCertificate: str
    clientCertificate: str
    clientKey: str
    connectRetryInterval: int
    dumpFilePath: str
    kind: str
    masterHeartbeatPeriod: str
    password: str
    sslCipher: str
    username: str
    verifyServerCertificate: bool

@typing.type_check_only
class MySqlSyncConfig(typing_extensions.TypedDict, total=False):
    initialSyncFlags: _list[SyncFlags]

@typing.type_check_only
class OnPremisesConfiguration(typing_extensions.TypedDict, total=False):
    caCertificate: str
    clientCertificate: str
    clientKey: str
    dumpFilePath: str
    hostPort: str
    kind: str
    password: str
    sourceInstance: InstanceReference
    username: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    backupContext: BackupContext
    endTime: str
    error: OperationErrors
    exportContext: ExportContext
    importContext: ImportContext
    insertTime: str
    kind: str
    name: str
    operationType: typing_extensions.Literal[
        "SQL_OPERATION_TYPE_UNSPECIFIED",
        "IMPORT",
        "EXPORT",
        "CREATE",
        "UPDATE",
        "DELETE",
        "RESTART",
        "BACKUP",
        "SNAPSHOT",
        "BACKUP_VOLUME",
        "DELETE_VOLUME",
        "RESTORE_VOLUME",
        "INJECT_USER",
        "CLONE",
        "STOP_REPLICA",
        "START_REPLICA",
        "PROMOTE_REPLICA",
        "CREATE_REPLICA",
        "CREATE_USER",
        "DELETE_USER",
        "UPDATE_USER",
        "CREATE_DATABASE",
        "DELETE_DATABASE",
        "UPDATE_DATABASE",
        "FAILOVER",
        "DELETE_BACKUP",
        "RECREATE_REPLICA",
        "TRUNCATE_LOG",
        "DEMOTE_MASTER",
        "MAINTENANCE",
        "ENABLE_PRIVATE_IP",
        "DEFER_MAINTENANCE",
        "CREATE_CLONE",
        "RESCHEDULE_MAINTENANCE",
        "START_EXTERNAL_SYNC",
        "LOG_CLEANUP",
        "AUTO_RESTART",
    ]
    selfLink: str
    startTime: str
    status: typing_extensions.Literal[
        "SQL_OPERATION_STATUS_UNSPECIFIED", "PENDING", "RUNNING", "DONE"
    ]
    targetId: str
    targetLink: str
    targetProject: str
    user: str

@typing.type_check_only
class OperationError(typing_extensions.TypedDict, total=False):
    code: str
    kind: str
    message: str

@typing.type_check_only
class OperationErrors(typing_extensions.TypedDict, total=False):
    errors: _list[OperationError]
    kind: str

@typing.type_check_only
class OperationsListResponse(typing_extensions.TypedDict, total=False):
    items: _list[Operation]
    kind: str
    nextPageToken: str

@typing.type_check_only
class PasswordStatus(typing_extensions.TypedDict, total=False):
    locked: bool
    passwordExpirationTime: str

@typing.type_check_only
class PasswordValidationPolicy(typing_extensions.TypedDict, total=False):
    complexity: typing_extensions.Literal[
        "COMPLEXITY_UNSPECIFIED", "COMPLEXITY_DEFAULT"
    ]
    disallowUsernameSubstring: bool
    enablePasswordPolicy: bool
    minLength: int
    passwordChangeInterval: str
    reuseInterval: int

@typing.type_check_only
class ReplicaConfiguration(typing_extensions.TypedDict, total=False):
    failoverTarget: bool
    kind: str
    mysqlReplicaConfiguration: MySqlReplicaConfiguration

@typing.type_check_only
class Reschedule(typing_extensions.TypedDict, total=False):
    rescheduleType: typing_extensions.Literal[
        "RESCHEDULE_TYPE_UNSPECIFIED",
        "IMMEDIATE",
        "NEXT_AVAILABLE_WINDOW",
        "SPECIFIC_TIME",
    ]
    scheduleTime: str

@typing.type_check_only
class RestoreBackupContext(typing_extensions.TypedDict, total=False):
    backupRunId: str
    instanceId: str
    kind: str
    project: str

@typing.type_check_only
class RotateServerCaContext(typing_extensions.TypedDict, total=False):
    kind: str
    nextVersion: str

@typing.type_check_only
class Settings(typing_extensions.TypedDict, total=False):
    activationPolicy: typing_extensions.Literal[
        "SQL_ACTIVATION_POLICY_UNSPECIFIED", "ALWAYS", "NEVER", "ON_DEMAND"
    ]
    activeDirectoryConfig: SqlActiveDirectoryConfig
    authorizedGaeApplications: _list[str]
    availabilityType: typing_extensions.Literal[
        "SQL_AVAILABILITY_TYPE_UNSPECIFIED", "ZONAL", "REGIONAL"
    ]
    backupConfiguration: BackupConfiguration
    collation: str
    connectorEnforcement: typing_extensions.Literal[
        "CONNECTOR_ENFORCEMENT_UNSPECIFIED", "NOT_REQUIRED", "REQUIRED"
    ]
    crashSafeReplicationEnabled: bool
    dataDiskSizeGb: str
    dataDiskType: typing_extensions.Literal[
        "SQL_DATA_DISK_TYPE_UNSPECIFIED", "PD_SSD", "PD_HDD", "OBSOLETE_LOCAL_SSD"
    ]
    databaseFlags: _list[DatabaseFlags]
    databaseReplicationEnabled: bool
    deletionProtectionEnabled: bool
    denyMaintenancePeriods: _list[DenyMaintenancePeriod]
    insightsConfig: InsightsConfig
    ipConfiguration: IpConfiguration
    kind: str
    locationPreference: LocationPreference
    maintenanceWindow: MaintenanceWindow
    passwordValidationPolicy: PasswordValidationPolicy
    pricingPlan: typing_extensions.Literal[
        "SQL_PRICING_PLAN_UNSPECIFIED", "PACKAGE", "PER_USE"
    ]
    replicationType: typing_extensions.Literal[
        "SQL_REPLICATION_TYPE_UNSPECIFIED", "SYNCHRONOUS", "ASYNCHRONOUS"
    ]
    settingsVersion: str
    sqlServerAuditConfig: SqlServerAuditConfig
    storageAutoResize: bool
    storageAutoResizeLimit: str
    tier: str
    timeZone: str
    userLabels: dict[str, typing.Any]

@typing.type_check_only
class SqlActiveDirectoryConfig(typing_extensions.TypedDict, total=False):
    domain: str
    kind: str

@typing.type_check_only
class SqlExternalSyncSettingError(typing_extensions.TypedDict, total=False):
    detail: str
    kind: str
    type: typing_extensions.Literal[
        "SQL_EXTERNAL_SYNC_SETTING_ERROR_TYPE_UNSPECIFIED",
        "CONNECTION_FAILURE",
        "BINLOG_NOT_ENABLED",
        "INCOMPATIBLE_DATABASE_VERSION",
        "REPLICA_ALREADY_SETUP",
        "INSUFFICIENT_PRIVILEGE",
        "UNSUPPORTED_MIGRATION_TYPE",
        "NO_PGLOGICAL_INSTALLED",
        "PGLOGICAL_NODE_ALREADY_EXISTS",
        "INVALID_WAL_LEVEL",
        "INVALID_SHARED_PRELOAD_LIBRARY",
        "INSUFFICIENT_MAX_REPLICATION_SLOTS",
        "INSUFFICIENT_MAX_WAL_SENDERS",
        "INSUFFICIENT_MAX_WORKER_PROCESSES",
        "UNSUPPORTED_EXTENSIONS",
        "INVALID_RDS_LOGICAL_REPLICATION",
        "INVALID_LOGGING_SETUP",
        "INVALID_DB_PARAM",
        "UNSUPPORTED_GTID_MODE",
        "SQLSERVER_AGENT_NOT_RUNNING",
        "UNSUPPORTED_TABLE_DEFINITION",
        "UNSUPPORTED_DEFINER",
        "SQLSERVER_SERVERNAME_MISMATCH",
        "PRIMARY_ALREADY_SETUP",
        "UNSUPPORTED_BINLOG_FORMAT",
        "BINLOG_RETENTION_SETTING",
        "UNSUPPORTED_STORAGE_ENGINE",
        "LIMITED_SUPPORT_TABLES",
    ]

@typing.type_check_only
class SqlInstancesRescheduleMaintenanceRequestBody(
    typing_extensions.TypedDict, total=False
):
    reschedule: Reschedule

@typing.type_check_only
class SqlInstancesStartExternalSyncRequest(typing_extensions.TypedDict, total=False):
    mysqlSyncConfig: MySqlSyncConfig
    skipVerification: bool
    syncMode: typing_extensions.Literal[
        "EXTERNAL_SYNC_MODE_UNSPECIFIED", "ONLINE", "OFFLINE"
    ]

@typing.type_check_only
class SqlInstancesVerifyExternalSyncSettingsRequest(
    typing_extensions.TypedDict, total=False
):
    mysqlSyncConfig: MySqlSyncConfig
    syncMode: typing_extensions.Literal[
        "EXTERNAL_SYNC_MODE_UNSPECIFIED", "ONLINE", "OFFLINE"
    ]
    verifyConnectionOnly: bool
    verifyReplicationOnly: bool

@typing.type_check_only
class SqlInstancesVerifyExternalSyncSettingsResponse(
    typing_extensions.TypedDict, total=False
):
    errors: _list[SqlExternalSyncSettingError]
    kind: str
    warnings: _list[SqlExternalSyncSettingError]

@typing.type_check_only
class SqlOutOfDiskReport(typing_extensions.TypedDict, total=False):
    sqlMinRecommendedIncreaseSizeGb: int
    sqlOutOfDiskState: typing_extensions.Literal[
        "SQL_OUT_OF_DISK_STATE_UNSPECIFIED", "NORMAL", "SOFT_SHUTDOWN"
    ]

@typing.type_check_only
class SqlScheduledMaintenance(typing_extensions.TypedDict, total=False):
    canDefer: bool
    canReschedule: bool
    scheduleDeadlineTime: str
    startTime: str

@typing.type_check_only
class SqlServerAuditConfig(typing_extensions.TypedDict, total=False):
    bucket: str
    kind: str
    retentionInterval: str
    uploadInterval: str

@typing.type_check_only
class SqlServerDatabaseDetails(typing_extensions.TypedDict, total=False):
    compatibilityLevel: int
    recoveryModel: str

@typing.type_check_only
class SqlServerUserDetails(typing_extensions.TypedDict, total=False):
    disabled: bool
    serverRoles: _list[str]

@typing.type_check_only
class SslCert(typing_extensions.TypedDict, total=False):
    cert: str
    certSerialNumber: str
    commonName: str
    createTime: str
    expirationTime: str
    instance: str
    kind: str
    selfLink: str
    sha1Fingerprint: str

@typing.type_check_only
class SslCertDetail(typing_extensions.TypedDict, total=False):
    certInfo: SslCert
    certPrivateKey: str

@typing.type_check_only
class SslCertsCreateEphemeralRequest(typing_extensions.TypedDict, total=False):
    access_token: str
    public_key: str

@typing.type_check_only
class SslCertsInsertRequest(typing_extensions.TypedDict, total=False):
    commonName: str

@typing.type_check_only
class SslCertsInsertResponse(typing_extensions.TypedDict, total=False):
    clientCert: SslCertDetail
    kind: str
    operation: Operation
    serverCaCert: SslCert

@typing.type_check_only
class SslCertsListResponse(typing_extensions.TypedDict, total=False):
    items: _list[SslCert]
    kind: str

@typing.type_check_only
class SyncFlags(typing_extensions.TypedDict, total=False):
    name: str
    value: str

@typing.type_check_only
class Tier(typing_extensions.TypedDict, total=False):
    DiskQuota: str
    RAM: str
    kind: str
    region: _list[str]
    tier: str

@typing.type_check_only
class TiersListResponse(typing_extensions.TypedDict, total=False):
    items: _list[Tier]
    kind: str

@typing.type_check_only
class TruncateLogContext(typing_extensions.TypedDict, total=False):
    kind: str
    logType: str

@typing.type_check_only
class User(typing_extensions.TypedDict, total=False):
    dualPasswordType: typing_extensions.Literal[
        "DUAL_PASSWORD_TYPE_UNSPECIFIED",
        "NO_MODIFY_DUAL_PASSWORD",
        "NO_DUAL_PASSWORD",
        "DUAL_PASSWORD",
    ]
    etag: str
    host: str
    instance: str
    kind: str
    name: str
    password: str
    passwordPolicy: UserPasswordValidationPolicy
    project: str
    sqlserverUserDetails: SqlServerUserDetails
    type: typing_extensions.Literal[
        "BUILT_IN", "CLOUD_IAM_USER", "CLOUD_IAM_SERVICE_ACCOUNT"
    ]

@typing.type_check_only
class UserPasswordValidationPolicy(typing_extensions.TypedDict, total=False):
    allowedFailedAttempts: int
    enableFailedAttemptsCheck: bool
    enablePasswordVerification: bool
    passwordExpirationDuration: str
    status: PasswordStatus

@typing.type_check_only
class UsersListResponse(typing_extensions.TypedDict, total=False):
    items: _list[User]
    kind: str
    nextPageToken: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CalendarResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AclResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, calendarId: str, ruleId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, calendarId: str, ruleId: str, **kwargs: typing.Any
        ) -> AclRuleHttpRequest: ...
        def insert(
            self,
            *,
            calendarId: str,
            body: AclRule = ...,
            sendNotifications: bool = ...,
            **kwargs: typing.Any
        ) -> AclRuleHttpRequest: ...
        def list(
            self,
            *,
            calendarId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            showDeleted: bool = ...,
            syncToken: str = ...,
            **kwargs: typing.Any
        ) -> AclHttpRequest: ...
        def list_next(
            self, previous_request: AclHttpRequest, previous_response: Acl
        ) -> AclHttpRequest | None: ...
        def patch(
            self,
            *,
            calendarId: str,
            ruleId: str,
            body: AclRule = ...,
            sendNotifications: bool = ...,
            **kwargs: typing.Any
        ) -> AclRuleHttpRequest: ...
        def update(
            self,
            *,
            calendarId: str,
            ruleId: str,
            body: AclRule = ...,
            sendNotifications: bool = ...,
            **kwargs: typing.Any
        ) -> AclRuleHttpRequest: ...
        def watch(
            self,
            *,
            calendarId: str,
            body: Channel = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            showDeleted: bool = ...,
            syncToken: str = ...,
            **kwargs: typing.Any
        ) -> ChannelHttpRequest: ...

    @typing.type_check_only
    class CalendarListResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, calendarId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, calendarId: str, **kwargs: typing.Any
        ) -> CalendarListEntryHttpRequest: ...
        def insert(
            self,
            *,
            body: CalendarListEntry = ...,
            colorRgbFormat: bool = ...,
            **kwargs: typing.Any
        ) -> CalendarListEntryHttpRequest: ...
        def list(
            self,
            *,
            maxResults: int = ...,
            minAccessRole: typing_extensions.Literal[
                "freeBusyReader", "owner", "reader", "writer"
            ] = ...,
            pageToken: str = ...,
            showDeleted: bool = ...,
            showHidden: bool = ...,
            syncToken: str = ...,
            **kwargs: typing.Any
        ) -> CalendarListHttpRequest: ...
        def list_next(
            self,
            previous_request: CalendarListHttpRequest,
            previous_response: CalendarList,
        ) -> CalendarListHttpRequest | None: ...
        def patch(
            self,
            *,
            calendarId: str,
            body: CalendarListEntry = ...,
            colorRgbFormat: bool = ...,
            **kwargs: typing.Any
        ) -> CalendarListEntryHttpRequest: ...
        def update(
            self,
            *,
            calendarId: str,
            body: CalendarListEntry = ...,
            colorRgbFormat: bool = ...,
            **kwargs: typing.Any
        ) -> CalendarListEntryHttpRequest: ...
        def watch(
            self,
            *,
            body: Channel = ...,
            maxResults: int = ...,
            minAccessRole: typing_extensions.Literal[
                "freeBusyReader", "owner", "reader", "writer"
            ] = ...,
            pageToken: str = ...,
            showDeleted: bool = ...,
            showHidden: bool = ...,
            syncToken: str = ...,
            **kwargs: typing.Any
        ) -> ChannelHttpRequest: ...

    @typing.type_check_only
    class CalendarsResource(googleapiclient.discovery.Resource):
        def clear(
            self, *, calendarId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def delete(
            self, *, calendarId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, calendarId: str, **kwargs: typing.Any
        ) -> CalendarHttpRequest: ...
        def insert(
            self, *, body: Calendar = ..., **kwargs: typing.Any
        ) -> CalendarHttpRequest: ...
        def patch(
            self, *, calendarId: str, body: Calendar = ..., **kwargs: typing.Any
        ) -> CalendarHttpRequest: ...
        def update(
            self, *, calendarId: str, body: Calendar = ..., **kwargs: typing.Any
        ) -> CalendarHttpRequest: ...

    @typing.type_check_only
    class ChannelsResource(googleapiclient.discovery.Resource):
        def stop(
            self, *, body: Channel = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class ColorsResource(googleapiclient.discovery.Resource):
        def get(self, **kwargs: typing.Any) -> ColorsHttpRequest: ...

    @typing.type_check_only
    class EventsResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            calendarId: str,
            eventId: str,
            sendNotifications: bool = ...,
            sendUpdates: typing_extensions.Literal["all", "externalOnly", "none"] = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            calendarId: str,
            eventId: str,
            alwaysIncludeEmail: bool = ...,
            maxAttendees: int = ...,
            timeZone: str = ...,
            **kwargs: typing.Any
        ) -> EventHttpRequest: ...
        def import_(
            self,
            *,
            calendarId: str,
            body: Event = ...,
            conferenceDataVersion: int = ...,
            supportsAttachments: bool = ...,
            **kwargs: typing.Any
        ) -> EventHttpRequest: ...
        def insert(
            self,
            *,
            calendarId: str,
            body: Event = ...,
            conferenceDataVersion: int = ...,
            maxAttendees: int = ...,
            sendNotifications: bool = ...,
            sendUpdates: typing_extensions.Literal["all", "externalOnly", "none"] = ...,
            supportsAttachments: bool = ...,
            **kwargs: typing.Any
        ) -> EventHttpRequest: ...
        def instances(
            self,
            *,
            calendarId: str,
            eventId: str,
            alwaysIncludeEmail: bool = ...,
            maxAttendees: int = ...,
            maxResults: int = ...,
            originalStart: str = ...,
            pageToken: str = ...,
            showDeleted: bool = ...,
            timeMax: str = ...,
            timeMin: str = ...,
            timeZone: str = ...,
            **kwargs: typing.Any
        ) -> EventsHttpRequest: ...
        def instances_next(
            self, previous_request: EventsHttpRequest, previous_response: Events
        ) -> EventsHttpRequest | None: ...
        def list(
            self,
            *,
            calendarId: str,
            alwaysIncludeEmail: bool = ...,
            iCalUID: str = ...,
            maxAttendees: int = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal["startTime", "updated"] = ...,
            pageToken: str = ...,
            privateExtendedProperty: str | _list[str] = ...,
            q: str = ...,
            sharedExtendedProperty: str | _list[str] = ...,
            showDeleted: bool = ...,
            showHiddenInvitations: bool = ...,
            singleEvents: bool = ...,
            syncToken: str = ...,
            timeMax: str = ...,
            timeMin: str = ...,
            timeZone: str = ...,
            updatedMin: str = ...,
            **kwargs: typing.Any
        ) -> EventsHttpRequest: ...
        def list_next(
            self, previous_request: EventsHttpRequest, previous_response: Events
        ) -> EventsHttpRequest | None: ...
        def move(
            self,
            *,
            calendarId: str,
            eventId: str,
            destination: str,
            sendNotifications: bool = ...,
            sendUpdates: typing_extensions.Literal["all", "externalOnly", "none"] = ...,
            **kwargs: typing.Any
        ) -> EventHttpRequest: ...
        def patch(
            self,
            *,
            calendarId: str,
            eventId: str,
            body: Event = ...,
            alwaysIncludeEmail: bool = ...,
            conferenceDataVersion: int = ...,
            maxAttendees: int = ...,
            sendNotifications: bool = ...,
            sendUpdates: typing_extensions.Literal["all", "externalOnly", "none"] = ...,
            supportsAttachments: bool = ...,
            **kwargs: typing.Any
        ) -> EventHttpRequest: ...
        def quickAdd(
            self,
            *,
            calendarId: str,
            text: str,
            sendNotifications: bool = ...,
            sendUpdates: typing_extensions.Literal["all", "externalOnly", "none"] = ...,
            **kwargs: typing.Any
        ) -> EventHttpRequest: ...
        def update(
            self,
            *,
            calendarId: str,
            eventId: str,
            body: Event = ...,
            alwaysIncludeEmail: bool = ...,
            conferenceDataVersion: int = ...,
            maxAttendees: int = ...,
            sendNotifications: bool = ...,
            sendUpdates: typing_extensions.Literal["all", "externalOnly", "none"] = ...,
            supportsAttachments: bool = ...,
            **kwargs: typing.Any
        ) -> EventHttpRequest: ...
        def watch(
            self,
            *,
            calendarId: str,
            body: Channel = ...,
            alwaysIncludeEmail: bool = ...,
            iCalUID: str = ...,
            maxAttendees: int = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal["startTime", "updated"] = ...,
            pageToken: str = ...,
            privateExtendedProperty: str | _list[str] = ...,
            q: str = ...,
            sharedExtendedProperty: str | _list[str] = ...,
            showDeleted: bool = ...,
            showHiddenInvitations: bool = ...,
            singleEvents: bool = ...,
            syncToken: str = ...,
            timeMax: str = ...,
            timeMin: str = ...,
            timeZone: str = ...,
            updatedMin: str = ...,
            **kwargs: typing.Any
        ) -> ChannelHttpRequest: ...

    @typing.type_check_only
    class FreebusyResource(googleapiclient.discovery.Resource):
        def query(
            self, *, body: FreeBusyRequest = ..., **kwargs: typing.Any
        ) -> FreeBusyResponseHttpRequest: ...

    @typing.type_check_only
    class SettingsResource(googleapiclient.discovery.Resource):
        def get(self, *, setting: str, **kwargs: typing.Any) -> SettingHttpRequest: ...
        def list(
            self,
            *,
            maxResults: int = ...,
            pageToken: str = ...,
            syncToken: str = ...,
            **kwargs: typing.Any
        ) -> SettingsHttpRequest: ...
        def list_next(
            self, previous_request: SettingsHttpRequest, previous_response: Settings
        ) -> SettingsHttpRequest | None: ...
        def watch(
            self,
            *,
            body: Channel = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            syncToken: str = ...,
            **kwargs: typing.Any
        ) -> ChannelHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def acl(self) -> AclResource: ...
    def calendarList(self) -> CalendarListResource: ...
    def calendars(self) -> CalendarsResource: ...
    def channels(self) -> ChannelsResource: ...
    def colors(self) -> ColorsResource: ...
    def events(self) -> EventsResource: ...
    def freebusy(self) -> FreebusyResource: ...
    def settings(self) -> SettingsResource: ...

@typing.type_check_only
class AclHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Acl: ...

@typing.type_check_only
class AclRuleHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AclRule: ...

@typing.type_check_only
class CalendarHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Calendar: ...

@typing.type_check_only
class CalendarListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CalendarList: ...

@typing.type_check_only
class CalendarListEntryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CalendarListEntry: ...

@typing.type_check_only
class ChannelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Channel: ...

@typing.type_check_only
class ColorsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Colors: ...

@typing.type_check_only
class EventHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Event: ...

@typing.type_check_only
class EventsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Events: ...

@typing.type_check_only
class FreeBusyResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FreeBusyResponse: ...

@typing.type_check_only
class SettingHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Setting: ...

@typing.type_check_only
class SettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Settings: ...



from _typeshed import Incomplete

logger: Incomplete
POSITIONAL_WARNING: str
POSITIONAL_EXCEPTION: str
POSITIONAL_IGNORE: str
POSITIONAL_SET: Incomplete
positional_parameters_enforcement = POSITIONAL_WARNING

def positional(max_positional_args): ...
def parse_unique_urlencoded(content): ...
def update_query_params(uri, params): ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuthorizationPolicy(typing_extensions.TypedDict, total=False):
    action: typing_extensions.Literal["ACTION_UNSPECIFIED", "ALLOW", "DENY"]
    createTime: str
    description: str
    labels: dict[str, typing.Any]
    name: str
    rules: _list[Rule]
    updateTime: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CertificateProviderInstance(typing_extensions.TypedDict, total=False):
    pluginInstance: str

@typing.type_check_only
class ClientTlsPolicy(typing_extensions.TypedDict, total=False):
    clientCertificate: GoogleCloudNetworksecurityV1beta1CertificateProvider
    createTime: str
    description: str
    labels: dict[str, typing.Any]
    name: str
    serverValidationCa: _list[ValidationCA]
    sni: str
    updateTime: str

@typing.type_check_only
class Destination(typing_extensions.TypedDict, total=False):
    hosts: _list[str]
    httpHeaderMatch: HttpHeaderMatch
    methods: _list[str]
    ports: _list[int]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GoogleCloudNetworksecurityV1beta1CertificateProvider(
    typing_extensions.TypedDict, total=False
):
    certificateProviderInstance: CertificateProviderInstance
    grpcEndpoint: GoogleCloudNetworksecurityV1beta1GrpcEndpoint

@typing.type_check_only
class GoogleCloudNetworksecurityV1beta1GrpcEndpoint(
    typing_extensions.TypedDict, total=False
):
    targetUri: str

@typing.type_check_only
class GoogleIamV1AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[GoogleIamV1AuditLogConfig]
    service: str

@typing.type_check_only
class GoogleIamV1AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class GoogleIamV1Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class GoogleIamV1Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[GoogleIamV1AuditConfig]
    bindings: _list[GoogleIamV1Binding]
    etag: str
    version: int

@typing.type_check_only
class GoogleIamV1SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: GoogleIamV1Policy
    updateMask: str

@typing.type_check_only
class GoogleIamV1TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class GoogleIamV1TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class HttpHeaderMatch(typing_extensions.TypedDict, total=False):
    headerName: str
    regexMatch: str

@typing.type_check_only
class ListAuthorizationPoliciesResponse(typing_extensions.TypedDict, total=False):
    authorizationPolicies: _list[AuthorizationPolicy]
    nextPageToken: str

@typing.type_check_only
class ListClientTlsPoliciesResponse(typing_extensions.TypedDict, total=False):
    clientTlsPolicies: _list[ClientTlsPolicy]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListServerTlsPoliciesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    serverTlsPolicies: _list[ServerTlsPolicy]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class MTLSPolicy(typing_extensions.TypedDict, total=False):
    clientValidationCa: _list[ValidationCA]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class Rule(typing_extensions.TypedDict, total=False):
    destinations: _list[Destination]
    sources: _list[Source]

@typing.type_check_only
class ServerTlsPolicy(typing_extensions.TypedDict, total=False):
    allowOpen: bool
    createTime: str
    description: str
    labels: dict[str, typing.Any]
    mtlsPolicy: MTLSPolicy
    name: str
    serverCertificate: GoogleCloudNetworksecurityV1beta1CertificateProvider
    updateTime: str

@typing.type_check_only
class Source(typing_extensions.TypedDict, total=False):
    ipBlocks: _list[str]
    principals: _list[str]

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class ValidationCA(typing_extensions.TypedDict, total=False):
    certificateProviderInstance: CertificateProviderInstance
    grpcEndpoint: GoogleCloudNetworksecurityV1beta1GrpcEndpoint



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudShellResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def cancel(
            self, *, name: str, body: CancelOperationRequest = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            name: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListOperationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListOperationsResponseHttpRequest,
            previous_response: ListOperationsResponse,
        ) -> ListOperationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class EnvironmentsResource(googleapiclient.discovery.Resource):
            def addPublicKey(
                self,
                *,
                environment: str,
                body: AddPublicKeyRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def authorize(
                self,
                *,
                name: str,
                body: AuthorizeEnvironmentRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> EnvironmentHttpRequest: ...
            def removePublicKey(
                self,
                *,
                environment: str,
                body: RemovePublicKeyRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def start(
                self,
                *,
                name: str,
                body: StartEnvironmentRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def environments(self) -> EnvironmentsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def operations(self) -> OperationsResource: ...
    def users(self) -> UsersResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class EnvironmentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Environment: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class ANR(typing_extensions.TypedDict, total=False):
    stackTrace: StackTrace

@typing.type_check_only
class AndroidAppInfo(typing_extensions.TypedDict, total=False):
    name: str
    packageName: str
    versionCode: str
    versionName: str

@typing.type_check_only
class AndroidInstrumentationTest(typing_extensions.TypedDict, total=False):
    testPackageId: str
    testRunnerClass: str
    testTargets: _list[str]
    useOrchestrator: bool

@typing.type_check_only
class AndroidRoboTest(typing_extensions.TypedDict, total=False):
    appInitialActivity: str
    bootstrapPackageId: str
    bootstrapRunnerClass: str
    maxDepth: int
    maxSteps: int

@typing.type_check_only
class AndroidTest(typing_extensions.TypedDict, total=False):
    androidAppInfo: AndroidAppInfo
    androidInstrumentationTest: AndroidInstrumentationTest
    androidRoboTest: AndroidRoboTest
    androidTestLoop: AndroidTestLoop
    testTimeout: Duration

@typing.type_check_only
class AndroidTestLoop(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Any(typing_extensions.TypedDict, total=False):
    typeUrl: str
    value: str

@typing.type_check_only
class AppStartTime(typing_extensions.TypedDict, total=False):
    fullyDrawnTime: Duration
    initialDisplayTime: Duration

@typing.type_check_only
class AvailableDeepLinks(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class BasicPerfSampleSeries(typing_extensions.TypedDict, total=False):
    perfMetricType: typing_extensions.Literal[
        "perfMetricTypeUnspecified", "memory", "cpu", "network", "graphics"
    ]
    perfUnit: typing_extensions.Literal[
        "perfUnitUnspecified",
        "kibibyte",
        "percent",
        "bytesPerSecond",
        "framesPerSecond",
        "byte",
    ]
    sampleSeriesLabel: typing_extensions.Literal[
        "sampleSeriesTypeUnspecified",
        "memoryRssPrivate",
        "memoryRssShared",
        "memoryRssTotal",
        "memoryTotal",
        "cpuUser",
        "cpuKernel",
        "cpuTotal",
        "ntBytesTransferred",
        "ntBytesReceived",
        "networkSent",
        "networkReceived",
        "graphicsFrameRate",
    ]

@typing.type_check_only
class BatchCreatePerfSamplesRequest(typing_extensions.TypedDict, total=False):
    perfSamples: _list[PerfSample]

@typing.type_check_only
class BatchCreatePerfSamplesResponse(typing_extensions.TypedDict, total=False):
    perfSamples: _list[PerfSample]

@typing.type_check_only
class BlankScreen(typing_extensions.TypedDict, total=False):
    screenId: str

@typing.type_check_only
class CPUInfo(typing_extensions.TypedDict, total=False):
    cpuProcessor: str
    cpuSpeedInGhz: float
    numberOfCores: int

@typing.type_check_only
class CrashDialogError(typing_extensions.TypedDict, total=False):
    crashPackage: str

@typing.type_check_only
class DetectedAppSplashScreen(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeviceOutOfMemory(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Duration(typing_extensions.TypedDict, total=False):
    nanos: int
    seconds: str

@typing.type_check_only
class EncounteredLoginScreen(typing_extensions.TypedDict, total=False):
    distinctScreens: int
    screenIds: _list[str]

@typing.type_check_only
class EncounteredNonAndroidUiWidgetScreen(typing_extensions.TypedDict, total=False):
    distinctScreens: int
    screenIds: _list[str]

@typing.type_check_only
class Environment(typing_extensions.TypedDict, total=False):
    completionTime: Timestamp
    creationTime: Timestamp
    dimensionValue: _list[EnvironmentDimensionValueEntry]
    displayName: str
    environmentId: str
    environmentResult: MergedResult
    executionId: str
    historyId: str
    projectId: str
    resultsStorage: ResultsStorage
    shardSummaries: _list[ShardSummary]

@typing.type_check_only
class EnvironmentDimensionValueEntry(typing_extensions.TypedDict, total=False):
    key: str
    value: str

@typing.type_check_only
class Execution(typing_extensions.TypedDict, total=False):
    completionTime: Timestamp
    creationTime: Timestamp
    dimensionDefinitions: _list[MatrixDimensionDefinition]
    executionId: str
    outcome: Outcome
    specification: Specification
    state: typing_extensions.Literal[
        "unknownState", "pending", "inProgress", "complete"
    ]
    testExecutionMatrixId: str

@typing.type_check_only
class FailedToInstall(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FailureDetail(typing_extensions.TypedDict, total=False):
    crashed: bool
    deviceOutOfMemory: bool
    failedRoboscript: bool
    notInstalled: bool
    otherNativeCrash: bool
    timedOut: bool
    unableToCrawl: bool

@typing.type_check_only
class FatalException(typing_extensions.TypedDict, total=False):
    stackTrace: StackTrace

@typing.type_check_only
class FileReference(typing_extensions.TypedDict, total=False):
    fileUri: str

@typing.type_check_only
class GraphicsStats(typing_extensions.TypedDict, total=False):
    buckets: _list[GraphicsStatsBucket]
    highInputLatencyCount: str
    jankyFrames: str
    missedVsyncCount: str
    p50Millis: str
    p90Millis: str
    p95Millis: str
    p99Millis: str
    slowBitmapUploadCount: str
    slowDrawCount: str
    slowUiThreadCount: str
    totalFrames: str

@typing.type_check_only
class GraphicsStatsBucket(typing_extensions.TypedDict, total=False):
    frameCount: str
    renderMillis: str

@typing.type_check_only
class History(typing_extensions.TypedDict, total=False):
    displayName: str
    historyId: str
    name: str
    testPlatform: typing_extensions.Literal["unknownPlatform", "android", "ios"]

@typing.type_check_only
class Image(typing_extensions.TypedDict, total=False):
    error: Status
    sourceImage: ToolOutputReference
    stepId: str
    thumbnail: Thumbnail

@typing.type_check_only
class InAppPurchasesFound(typing_extensions.TypedDict, total=False):
    inAppPurchasesFlowsExplored: int
    inAppPurchasesFlowsStarted: int

@typing.type_check_only
class InconclusiveDetail(typing_extensions.TypedDict, total=False):
    abortedByUser: bool
    hasErrorLogs: bool
    infrastructureFailure: bool

@typing.type_check_only
class IndividualOutcome(typing_extensions.TypedDict, total=False):
    multistepNumber: int
    outcomeSummary: typing_extensions.Literal[
        "unset", "success", "failure", "inconclusive", "skipped", "flaky"
    ]
    runDuration: Duration
    stepId: str

@typing.type_check_only
class InsufficientCoverage(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class IosAppCrashed(typing_extensions.TypedDict, total=False):
    stackTrace: StackTrace

@typing.type_check_only
class IosAppInfo(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class IosRoboTest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class IosTest(typing_extensions.TypedDict, total=False):
    iosAppInfo: IosAppInfo
    iosRoboTest: IosRoboTest
    iosTestLoop: IosTestLoop
    iosXcTest: IosXcTest
    testTimeout: Duration

@typing.type_check_only
class IosTestLoop(typing_extensions.TypedDict, total=False):
    bundleId: str

@typing.type_check_only
class IosXcTest(typing_extensions.TypedDict, total=False):
    bundleId: str
    xcodeVersion: str

@typing.type_check_only
class LauncherActivityNotFound(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ListEnvironmentsResponse(typing_extensions.TypedDict, total=False):
    environments: _list[Environment]
    executionId: str
    historyId: str
    nextPageToken: str
    projectId: str

@typing.type_check_only
class ListExecutionsResponse(typing_extensions.TypedDict, total=False):
    executions: _list[Execution]
    nextPageToken: str

@typing.type_check_only
class ListHistoriesResponse(typing_extensions.TypedDict, total=False):
    histories: _list[History]
    nextPageToken: str

@typing.type_check_only
class ListPerfSampleSeriesResponse(typing_extensions.TypedDict, total=False):
    perfSampleSeries: _list[PerfSampleSeries]

@typing.type_check_only
class ListPerfSamplesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    perfSamples: _list[PerfSample]

@typing.type_check_only
class ListScreenshotClustersResponse(typing_extensions.TypedDict, total=False):
    clusters: _list[ScreenshotCluster]

@typing.type_check_only
class ListStepAccessibilityClustersResponse(typing_extensions.TypedDict, total=False):
    clusters: _list[SuggestionClusterProto]
    name: str

@typing.type_check_only
class ListStepThumbnailsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    thumbnails: _list[Image]

@typing.type_check_only
class ListStepsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    steps: _list[Step]

@typing.type_check_only
class ListTestCasesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    testCases: _list[TestCase]

@typing.type_check_only
class LogcatCollectionError(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class MatrixDimensionDefinition(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class MemoryInfo(typing_extensions.TypedDict, total=False):
    memoryCapInKibibyte: str
    memoryTotalInKibibyte: str

@typing.type_check_only
class MergedResult(typing_extensions.TypedDict, total=False):
    outcome: Outcome
    state: typing_extensions.Literal[
        "unknownState", "pending", "inProgress", "complete"
    ]
    testSuiteOverviews: _list[TestSuiteOverview]

@typing.type_check_only
class MultiStep(typing_extensions.TypedDict, total=False):
    multistepNumber: int
    primaryStep: PrimaryStep
    primaryStepId: str

@typing.type_check_only
class NativeCrash(typing_extensions.TypedDict, total=False):
    stackTrace: StackTrace

@typing.type_check_only
class NonSdkApi(typing_extensions.TypedDict, total=False):
    apiSignature: str
    exampleStackTraces: _list[str]
    insights: _list[NonSdkApiInsight]
    invocationCount: int
    list: typing_extensions.Literal[
        "NONE",
        "WHITE",
        "BLACK",
        "GREY",
        "GREY_MAX_O",
        "GREY_MAX_P",
        "GREY_MAX_Q",
        "GREY_MAX_R",
    ]

@typing.type_check_only
class NonSdkApiInsight(typing_extensions.TypedDict, total=False):
    exampleTraceMessages: _list[str]
    matcherId: str
    pendingGoogleUpdateInsight: PendingGoogleUpdateInsight
    upgradeInsight: UpgradeInsight

@typing.type_check_only
class NonSdkApiUsageViolation(typing_extensions.TypedDict, total=False):
    apiSignatures: _list[str]
    uniqueApis: int

@typing.type_check_only
class NonSdkApiUsageViolationReport(typing_extensions.TypedDict, total=False):
    exampleApis: _list[NonSdkApi]
    minSdkVersion: int
    targetSdkVersion: int
    uniqueApis: int

@typing.type_check_only
class Outcome(typing_extensions.TypedDict, total=False):
    failureDetail: FailureDetail
    inconclusiveDetail: InconclusiveDetail
    skippedDetail: SkippedDetail
    successDetail: SuccessDetail
    summary: typing_extensions.Literal[
        "unset", "success", "failure", "inconclusive", "skipped", "flaky"
    ]

@typing.type_check_only
class OverlappingUIElements(typing_extensions.TypedDict, total=False):
    resourceName: _list[str]
    screenId: str

@typing.type_check_only
class PendingGoogleUpdateInsight(typing_extensions.TypedDict, total=False):
    nameOfGoogleLibrary: str

@typing.type_check_only
class PerfEnvironment(typing_extensions.TypedDict, total=False):
    cpuInfo: CPUInfo
    memoryInfo: MemoryInfo

@typing.type_check_only
class PerfMetricsSummary(typing_extensions.TypedDict, total=False):
    appStartTime: AppStartTime
    executionId: str
    graphicsStats: GraphicsStats
    historyId: str
    perfEnvironment: PerfEnvironment
    perfMetrics: _list[str]
    projectId: str
    stepId: str

@typing.type_check_only
class PerfSample(typing_extensions.TypedDict, total=False):
    sampleTime: Timestamp
    value: float

@typing.type_check_only
class PerfSampleSeries(typing_extensions.TypedDict, total=False):
    basicPerfSampleSeries: BasicPerfSampleSeries
    executionId: str
    historyId: str
    projectId: str
    sampleSeriesId: str
    stepId: str

@typing.type_check_only
class PerformedGoogleLogin(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class PerformedMonkeyActions(typing_extensions.TypedDict, total=False):
    totalActions: int

@typing.type_check_only
class PrimaryStep(typing_extensions.TypedDict, total=False):
    individualOutcome: _list[IndividualOutcome]
    rollUp: typing_extensions.Literal[
        "unset", "success", "failure", "inconclusive", "skipped", "flaky"
    ]

@typing.type_check_only
class ProjectSettings(typing_extensions.TypedDict, total=False):
    defaultBucket: str
    name: str

@typing.type_check_only
class PublishXunitXmlFilesRequest(typing_extensions.TypedDict, total=False):
    xunitXmlFiles: _list[FileReference]

@typing.type_check_only
class RegionProto(typing_extensions.TypedDict, total=False):
    heightPx: int
    leftPx: int
    topPx: int
    widthPx: int

@typing.type_check_only
class ResultsStorage(typing_extensions.TypedDict, total=False):
    resultsStoragePath: FileReference
    xunitXmlFile: FileReference

@typing.type_check_only
class RoboScriptExecution(typing_extensions.TypedDict, total=False):
    successfulActions: int
    totalActions: int

@typing.type_check_only
class SafeHtmlProto(typing_extensions.TypedDict, total=False):
    privateDoNotAccessOrElseSafeHtmlWrappedValue: str

@typing.type_check_only
class Screen(typing_extensions.TypedDict, total=False):
    fileReference: str
    locale: str
    model: str
    version: str

@typing.type_check_only
class ScreenshotCluster(typing_extensions.TypedDict, total=False):
    activity: str
    clusterId: str
    keyScreen: Screen
    screens: _list[Screen]

@typing.type_check_only
class ShardSummary(typing_extensions.TypedDict, total=False):
    runs: _list[StepSummary]
    shardResult: MergedResult

@typing.type_check_only
class SkippedDetail(typing_extensions.TypedDict, total=False):
    incompatibleAppVersion: bool
    incompatibleArchitecture: bool
    incompatibleDevice: bool

@typing.type_check_only
class Specification(typing_extensions.TypedDict, total=False):
    androidTest: AndroidTest
    iosTest: IosTest

@typing.type_check_only
class StackTrace(typing_extensions.TypedDict, total=False):
    exception: str

@typing.type_check_only
class StartActivityNotFound(typing_extensions.TypedDict, total=False):
    action: str
    uri: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class Step(typing_extensions.TypedDict, total=False):
    completionTime: Timestamp
    creationTime: Timestamp
    description: str
    deviceUsageDuration: Duration
    dimensionValue: _list[StepDimensionValueEntry]
    hasImages: bool
    labels: _list[StepLabelsEntry]
    multiStep: MultiStep
    name: str
    outcome: Outcome
    runDuration: Duration
    state: typing_extensions.Literal[
        "unknownState", "pending", "inProgress", "complete"
    ]
    stepId: str
    testExecutionStep: TestExecutionStep
    toolExecutionStep: ToolExecutionStep

@typing.type_check_only
class StepDimensionValueEntry(typing_extensions.TypedDict, total=False):
    key: str
    value: str

@typing.type_check_only
class StepLabelsEntry(typing_extensions.TypedDict, total=False):
    key: str
    value: str

@typing.type_check_only
class StepSummary(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SuccessDetail(typing_extensions.TypedDict, total=False):
    otherNativeCrash: bool

@typing.type_check_only
class SuggestionClusterProto(typing_extensions.TypedDict, total=False):
    category: typing_extensions.Literal[
        "unknownCategory",
        "contentLabeling",
        "touchTargetSize",
        "lowContrast",
        "implementation",
    ]
    suggestions: _list[SuggestionProto]

@typing.type_check_only
class SuggestionProto(typing_extensions.TypedDict, total=False):
    helpUrl: str
    longMessage: SafeHtmlProto
    priority: typing_extensions.Literal["unknownPriority", "error", "warning", "info"]
    pseudoResourceId: str
    region: RegionProto
    resourceName: str
    screenId: str
    secondaryPriority: float
    shortMessage: SafeHtmlProto
    title: str

@typing.type_check_only
class TestCase(typing_extensions.TypedDict, total=False):
    elapsedTime: Duration
    endTime: Timestamp
    skippedMessage: str
    stackTraces: _list[StackTrace]
    startTime: Timestamp
    status: typing_extensions.Literal["passed", "failed", "error", "skipped", "flaky"]
    testCaseId: str
    testCaseReference: TestCaseReference
    toolOutputs: _list[ToolOutputReference]

@typing.type_check_only
class TestCaseReference(typing_extensions.TypedDict, total=False):
    className: str
    name: str
    testSuiteName: str

@typing.type_check_only
class TestExecutionStep(typing_extensions.TypedDict, total=False):
    testIssues: _list[TestIssue]
    testSuiteOverviews: _list[TestSuiteOverview]
    testTiming: TestTiming
    toolExecution: ToolExecution

@typing.type_check_only
class TestIssue(typing_extensions.TypedDict, total=False):
    category: typing_extensions.Literal["unspecifiedCategory", "common", "robo"]
    errorMessage: str
    severity: typing_extensions.Literal[
        "unspecifiedSeverity", "info", "suggestion", "warning", "severe"
    ]
    stackTrace: StackTrace
    type: typing_extensions.Literal[
        "unspecifiedType",
        "fatalException",
        "nativeCrash",
        "anr",
        "unusedRoboDirective",
        "compatibleWithOrchestrator",
        "launcherActivityNotFound",
        "startActivityNotFound",
        "incompleteRoboScriptExecution",
        "completeRoboScriptExecution",
        "failedToInstall",
        "availableDeepLinks",
        "nonSdkApiUsageViolation",
        "nonSdkApiUsageReport",
        "encounteredNonAndroidUiWidgetScreen",
        "encounteredLoginScreen",
        "performedGoogleLogin",
        "iosException",
        "iosCrash",
        "performedMonkeyActions",
        "usedRoboDirective",
        "usedRoboIgnoreDirective",
        "insufficientCoverage",
        "inAppPurchases",
        "crashDialogError",
        "uiElementsTooDeep",
        "blankScreen",
        "overlappingUiElements",
        "unityException",
        "deviceOutOfMemory",
        "logcatCollectionError",
        "detectedAppSplashScreen",
    ]
    warning: Any

@typing.type_check_only
class TestSuiteOverview(typing_extensions.TypedDict, total=False):
    elapsedTime: Duration
    errorCount: int
    failureCount: int
    flakyCount: int
    name: str
    skippedCount: int
    totalCount: int
    xmlSource: FileReference

@typing.type_check_only
class TestTiming(typing_extensions.TypedDict, total=False):
    testProcessDuration: Duration

@typing.type_check_only
class Thumbnail(typing_extensions.TypedDict, total=False):
    contentType: str
    data: str
    heightPx: int
    widthPx: int

@typing.type_check_only
class Timestamp(typing_extensions.TypedDict, total=False):
    nanos: int
    seconds: str

@typing.type_check_only
class ToolExecution(typing_extensions.TypedDict, total=False):
    commandLineArguments: _list[str]
    exitCode: ToolExitCode
    toolLogs: _list[FileReference]
    toolOutputs: _list[ToolOutputReference]

@typing.type_check_only
class ToolExecutionStep(typing_extensions.TypedDict, total=False):
    toolExecution: ToolExecution

@typing.type_check_only
class ToolExitCode(typing_extensions.TypedDict, total=False):
    number: int

@typing.type_check_only
class ToolOutputReference(typing_extensions.TypedDict, total=False):
    creationTime: Timestamp
    output: FileReference
    testCase: TestCaseReference

@typing.type_check_only
class UIElementTooDeep(typing_extensions.TypedDict, total=False):
    depth: int
    screenId: str
    screenStateId: str

@typing.type_check_only
class UnspecifiedWarning(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UnusedRoboDirective(typing_extensions.TypedDict, total=False):
    resourceName: str

@typing.type_check_only
class UpgradeInsight(typing_extensions.TypedDict, total=False):
    packageName: str
    upgradeToVersion: str

@typing.type_check_only
class UsedRoboDirective(typing_extensions.TypedDict, total=False):
    resourceName: str

@typing.type_check_only
class UsedRoboIgnoreDirective(typing_extensions.TypedDict, total=False):
    resourceName: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class CloudStorageWorkload(typing_extensions.TypedDict, total=False):
    dataRetrieval: Usage
    dataStored: Usage
    dualRegion: DualRegional
    multiRegion: MultiRegional
    operationA: Usage
    operationB: Usage
    region: Regional
    storageClass: str

@typing.type_check_only
class Commitment(typing_extensions.TypedDict, total=False):
    name: str
    vmResourceBasedCud: VmResourceBasedCud

@typing.type_check_only
class CommitmentCostEstimate(typing_extensions.TypedDict, total=False):
    commitmentTotalCostEstimate: CostEstimate
    name: str
    skuCostEstimates: _list[SkuCostEstimate]

@typing.type_check_only
class ComputeVmWorkload(typing_extensions.TypedDict, total=False):
    enableConfidentialCompute: bool
    guestAccelerator: GuestAccelerator
    instancesRunning: Usage
    licenses: _list[str]
    machineType: MachineType
    persistentDisks: _list[PersistentDisk]
    preemptible: bool
    region: str

@typing.type_check_only
class CostEstimate(typing_extensions.TypedDict, total=False):
    creditEstimates: _list[CreditEstimate]
    netCostEstimate: Money
    preCreditCostEstimate: Money

@typing.type_check_only
class CostEstimationResult(typing_extensions.TypedDict, total=False):
    currencyCode: str
    segmentCostEstimates: _list[SegmentCostEstimate]
    skus: _list[Sku]

@typing.type_check_only
class CostScenario(typing_extensions.TypedDict, total=False):
    commitments: _list[Commitment]
    scenarioConfig: ScenarioConfig
    workloads: _list[Workload]

@typing.type_check_only
class CreditEstimate(typing_extensions.TypedDict, total=False):
    creditAmount: Money
    creditDescription: str
    creditType: str

@typing.type_check_only
class CustomMachineType(typing_extensions.TypedDict, total=False):
    machineSeries: str
    memorySizeGb: float
    virtualCpuCount: str

@typing.type_check_only
class DualRegional(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class EstimateCostScenarioForBillingAccountRequest(
    typing_extensions.TypedDict, total=False
):
    costScenario: CostScenario

@typing.type_check_only
class EstimateCostScenarioForBillingAccountResponse(
    typing_extensions.TypedDict, total=False
):
    costEstimationResult: CostEstimationResult

@typing.type_check_only
class EstimateCostScenarioWithListPriceRequest(
    typing_extensions.TypedDict, total=False
):
    costScenario: CostScenario

@typing.type_check_only
class EstimateCostScenarioWithListPriceResponse(
    typing_extensions.TypedDict, total=False
):
    costEstimationResult: CostEstimationResult

@typing.type_check_only
class EstimationTimePoint(typing_extensions.TypedDict, total=False):
    estimationTimeFrameOffset: str

@typing.type_check_only
class GuestAccelerator(typing_extensions.TypedDict, total=False):
    acceleratorCount: str
    acceleratorType: str

@typing.type_check_only
class MachineType(typing_extensions.TypedDict, total=False):
    customMachineType: CustomMachineType
    predefinedMachineType: PredefinedMachineType

@typing.type_check_only
class Money(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class MultiRegional(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class PersistentDisk(typing_extensions.TypedDict, total=False):
    diskSize: Usage
    diskType: str
    provisionedIops: Usage
    scope: typing_extensions.Literal[
        "SCOPE_UNSPECIFIED", "SCOPE_ZONAL", "SCOPE_REGIONAL"
    ]

@typing.type_check_only
class PredefinedMachineType(typing_extensions.TypedDict, total=False):
    machineType: str

@typing.type_check_only
class Price(typing_extensions.TypedDict, total=False):
    effectiveTime: EstimationTimePoint
    priceType: str
    rate: Rate

@typing.type_check_only
class Rate(typing_extensions.TypedDict, total=False):
    tiers: _list[RateTier]
    unit: str
    unitCount: float

@typing.type_check_only
class RateTier(typing_extensions.TypedDict, total=False):
    price: Money
    startAmount: float

@typing.type_check_only
class Regional(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class ScenarioConfig(typing_extensions.TypedDict, total=False):
    estimateDuration: str

@typing.type_check_only
class SegmentCostEstimate(typing_extensions.TypedDict, total=False):
    commitmentCostEstimates: _list[CommitmentCostEstimate]
    segmentStartTime: EstimationTimePoint
    segmentTotalCostEstimate: CostEstimate
    workloadCostEstimates: _list[WorkloadCostEstimate]

@typing.type_check_only
class Sku(typing_extensions.TypedDict, total=False):
    displayName: str
    prices: _list[Price]
    sku: str

@typing.type_check_only
class SkuCostEstimate(typing_extensions.TypedDict, total=False):
    costEstimate: CostEstimate
    sku: str
    usageAmount: float
    usageUnit: str

@typing.type_check_only
class Usage(typing_extensions.TypedDict, total=False):
    usageRateTimeline: UsageRateTimeline

@typing.type_check_only
class UsageRateTimeline(typing_extensions.TypedDict, total=False):
    unit: str
    usageRateTimelineEntries: _list[UsageRateTimelineEntry]

@typing.type_check_only
class UsageRateTimelineEntry(typing_extensions.TypedDict, total=False):
    effectiveTime: EstimationTimePoint
    usageRate: float

@typing.type_check_only
class VmResourceBasedCud(typing_extensions.TypedDict, total=False):
    guestAccelerator: GuestAccelerator
    machineSeries: str
    memorySizeGb: float
    plan: typing_extensions.Literal[
        "COMMITMENT_PLAN_UNSPECIFIED", "TWELVE_MONTH", "THIRTY_SIX_MONTH"
    ]
    region: str
    virtualCpuCount: str

@typing.type_check_only
class Workload(typing_extensions.TypedDict, total=False):
    cloudStorageWorkload: CloudStorageWorkload
    computeVmWorkload: ComputeVmWorkload
    name: str

@typing.type_check_only
class WorkloadCostEstimate(typing_extensions.TypedDict, total=False):
    name: str
    skuCostEstimates: _list[SkuCostEstimate]
    workloadTotalCostEstimate: CostEstimate



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class RealTimeBiddingResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class BiddersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class BiddingFunctionsResource(googleapiclient.discovery.Resource):
            def activate(
                self,
                *,
                name: str,
                body: ActivateBiddingFunctionRequest = ...,
                **kwargs: typing.Any
            ) -> BiddingFunctionHttpRequest: ...
            def archive(
                self,
                *,
                name: str,
                body: ArchiveBiddingFunctionRequest = ...,
                **kwargs: typing.Any
            ) -> BiddingFunctionHttpRequest: ...
            def create(
                self, *, parent: str, body: BiddingFunction = ..., **kwargs: typing.Any
            ) -> BiddingFunctionHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListBiddingFunctionsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListBiddingFunctionsResponseHttpRequest,
                previous_response: ListBiddingFunctionsResponse,
            ) -> ListBiddingFunctionsResponseHttpRequest | None: ...

        def biddingFunctions(self) -> BiddingFunctionsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def bidders(self) -> BiddersResource: ...

@typing.type_check_only
class BiddingFunctionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BiddingFunction: ...

@typing.type_check_only
class ListBiddingFunctionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBiddingFunctionsResponse: ...
